@@ -1,23 +1,24 @@
 module Stackctl.AWS.CloudFormation
-  ( Stack(..)
+  ( Stack (..)
   , stack_stackName
+  , stack_stackStatus
   , stackDescription
   , stackStatusRequiresDeletion
-  , StackId(..)
-  , StackName(..)
-  , StackDescription(..)
-  , StackStatus(..)
-  , StackEvent(..)
-  , ResourceStatus(..)
+  , StackId (..)
+  , StackName (..)
+  , StackDescription (..)
+  , StackStatus (..)
+  , StackEvent (..)
+  , ResourceStatus (..)
   , stackEvent_eventId
   , stackEvent_logicalResourceId
   , stackEvent_resourceStatus
   , stackEvent_resourceStatusReason
   , stackEvent_timestamp
-  , StackTemplate(..)
-  , StackDeployResult(..)
+  , StackTemplate (..)
+  , StackDeployResult (..)
   , prettyStackDeployResult
-  , StackDeleteResult(..)
+  , StackDeleteResult (..)
   , prettyStackDeleteResult
   , Parameter
   , parameter_parameterKey
@@ -25,7 +26,7 @@ module Stackctl.AWS.CloudFormation
   , newParameter
   , makeParameter
   , readParameter
-  , Capability(..)
+  , Capability (..)
   , Tag
   , newTag
   , tag_key
@@ -43,20 +44,21 @@ module Stackctl.AWS.CloudFormation
   , awsCloudFormationWait
   , awsCloudFormationGetTemplate
 
-  -- * ChangeSets
-  , ChangeSet(..)
+    -- * ChangeSets
+  , ChangeSet (..)
+  , changeSetFromResponse
   , changeSetJSON
-  , ChangeSetId(..)
-  , ChangeSetName(..)
-  , Change(..)
-  , ResourceChange(..)
-  , Replacement(..)
-  , ChangeAction(..)
-  , ResourceAttribute(..)
-  , ResourceChangeDetail(..)
-  , ChangeSource(..)
-  , ResourceTargetDefinition(..)
-  , RequiresRecreation(..)
+  , ChangeSetId (..)
+  , ChangeSetName (..)
+  , Change (..)
+  , ResourceChange (..)
+  , Replacement (..)
+  , ChangeAction (..)
+  , ResourceAttribute (..)
+  , ResourceChangeDetail (..)
+  , ChangeSource (..)
+  , ResourceTargetDefinition (..)
+  , RequiresRecreation (..)
   , awsCloudFormationCreateChangeSet
   , awsCloudFormationExecuteChangeSet
   , awsCloudFormationDeleteAllChangeSets
@@ -80,13 +82,11 @@ import Amazonka.CloudFormation.Waiters
 import Amazonka.Core
   ( AsError
   , ServiceError
+  , hasStatus
   , _MatchServiceError
   , _ServiceError
-  , hasStatus
-  , serviceCode
-  , serviceMessage
   )
-import Amazonka.Waiter (Accept(..))
+import Amazonka.Waiter (Accept (..))
 import Conduit
 import Control.Lens ((?~))
 import Data.Aeson
@@ -127,14 +127,14 @@ data StackDeployResult
   | StackCreateFailure Bool
   | StackUpdateSuccess
   | StackUpdateFailure Bool
-  deriving stock Show
+  deriving stock (Show)
 
 prettyStackDeployResult :: StackDeployResult -> Text
 prettyStackDeployResult = \case
   StackCreateSuccess -> "Created Stack successfully"
-  StackCreateFailure{} -> "Failed to create Stack"
+  StackCreateFailure {} -> "Failed to create Stack"
   StackUpdateSuccess -> "Updated Stack successfully"
-  StackUpdateFailure{} -> "Failed to update Stack"
+  StackUpdateFailure {} -> "Failed to update Stack"
 
 stackCreateResult :: Accept -> StackDeployResult
 stackCreateResult = \case
@@ -155,7 +155,7 @@ data StackDeleteResult
 prettyStackDeleteResult :: StackDeleteResult -> Text
 prettyStackDeleteResult = \case
   StackDeleteSuccess -> "Deleted Stack successfully"
-  StackDeleteFailure{} -> "Failed to delete Stack"
+  StackDeleteFailure {} -> "Failed to delete Stack"
 
 stackDeleteResult :: Accept -> StackDeleteResult
 stackDeleteResult = \case
@@ -174,10 +174,9 @@ newChangeSetName = liftIO $ do
 awsCloudFormationDescribeStack
   :: (MonadResource m, MonadReader env m, HasAwsEnv env) => StackName -> m Stack
 awsCloudFormationDescribeStack stackName = do
-  let
-    req = newDescribeStacks & describeStacks_stackName ?~ unStackName stackName
+  let req = newDescribeStacks & describeStacks_stackName ?~ unStackName stackName
 
-  awsSimple "DescribeStack" req $ \resp -> do
+  awsSimple req $ \resp -> do
     stacks <- resp ^. describeStacksResponse_stacks
     listToMaybe stacks
 
@@ -188,8 +187,10 @@ awsCloudFormationDescribeStackMaybe
 awsCloudFormationDescribeStackMaybe stackName =
   -- AWS gives us a 400 if the stackName doesn't exist, rather than simply
   -- returning an empty list, so we need to do this through exceptions
-  handling_ _ValidationError (pure Nothing) $ do
-    Just <$> awsCloudFormationDescribeStack stackName
+  handling_ _ValidationError (pure Nothing)
+    $ awsSilently -- don't log said 400
+    $ Just
+    <$> awsCloudFormationDescribeStack stackName
 
 awsCloudFormationDescribeStackOutputs
   :: (MonadResource m, MonadReader env m, HasAwsEnv env)
@@ -202,14 +203,14 @@ awsCloudFormationDescribeStackOutputs stackName = do
 awsCloudFormationDescribeStackEvents
   :: (MonadResource m, MonadReader env m, HasAwsEnv env)
   => StackName
-  -> Maybe Text -- ^ Last-seen Id
+  -> Maybe Text
+  -- ^ Last-seen Id
   -> m [StackEvent]
 awsCloudFormationDescribeStackEvents stackName mLastId = do
-  let
-    req =
-      newDescribeStackEvents
-        & describeStackEvents_stackName
-        ?~ unStackName stackName
+  let req =
+        newDescribeStackEvents
+          & describeStackEvents_stackName
+          ?~ unStackName stackName
 
   runConduit
     $ awsPaginate req
@@ -251,7 +252,7 @@ awsCloudFormationGetMostRecentStackEventId stackName = do
       [] -> Nothing
       (e : _) -> Just $ e ^. stackEvent_eventId
 
-  awsSimple "DescribeStackEvents" req
+  awsSimple req
     $ pure
     . getFirstEventId
     . fromMaybe []
@@ -267,7 +268,7 @@ awsCloudFormationDeleteStack stackName = do
     describeReq =
       newDescribeStacks & describeStacks_stackName ?~ unStackName stackName
 
-  awsSimple "DeleteStack" deleteReq $ const $ pure ()
+  awsSimple deleteReq $ const $ pure ()
 
   logDebug "Awaiting DeleteStack"
   stackDeleteResult <$> awsAwait newStackDeleteComplete describeReq
@@ -277,9 +278,10 @@ awsCloudFormationWait
   => StackName
   -> m StackDeployResult
 awsCloudFormationWait stackName = do
-  either stackCreateResult stackUpdateResult <$> race
-    (awsAwait newStackCreateComplete req)
-    (awsAwait newStackUpdateComplete req)
+  either stackCreateResult stackUpdateResult
+    <$> race
+      (awsAwait newStackCreateComplete req)
+      (awsAwait newStackUpdateComplete req)
  where
   req = newDescribeStacks & describeStacks_stackName ?~ unStackName stackName
 
@@ -296,7 +298,7 @@ awsCloudFormationGetTemplate stackName = do
     decodeTemplateBody body =
       fromMaybe (toJSON body) $ decodeStrict $ encodeUtf8 body
 
-  awsSimple "GetTemplate" req $ \resp -> do
+  awsSimple req $ \resp -> do
     body <- resp ^. getTemplateResponse_templateBody
     pure $ decodeTemplateBody body
 
@@ -339,6 +341,23 @@ data ChangeSet = ChangeSet
   , csResponse :: DescribeChangeSetResponse
   }
 
+changeSetFromResponse :: DescribeChangeSetResponse -> Maybe ChangeSet
+changeSetFromResponse resp =
+  ChangeSet
+    <$> (resp ^. describeChangeSetResponse_creationTime)
+    <*> pure (fmap sortChanges $ resp ^. describeChangeSetResponse_changes)
+    <*> (ChangeSetName <$> resp ^. describeChangeSetResponse_changeSetName)
+    <*> (resp ^. describeChangeSetResponse_executionStatus)
+    <*> (ChangeSetId <$> resp ^. describeChangeSetResponse_changeSetId)
+    <*> pure (resp ^. describeChangeSetResponse_parameters)
+    <*> (StackId <$> resp ^. describeChangeSetResponse_stackId)
+    <*> pure (resp ^. describeChangeSetResponse_capabilities)
+    <*> pure (resp ^. describeChangeSetResponse_tags)
+    <*> (StackName <$> resp ^. describeChangeSetResponse_stackName)
+    <*> pure (resp ^. describeChangeSetResponse_status)
+    <*> pure (resp ^. describeChangeSetResponse_statusReason)
+    <*> pure resp
+
 changeSetJSON :: ChangeSet -> Text
 changeSetJSON = decodeUtf8 . BSL.toStrict . encodePretty . csResponse
 
@@ -359,27 +378,28 @@ awsCloudFormationCreateChangeSet
   -> [Capability]
   -> [Tag]
   -> m (Either Text (Maybe ChangeSet))
-awsCloudFormationCreateChangeSet stackName mStackDescription stackTemplate parameters capabilities tags
-  = fmap (first formatServiceError)
+awsCloudFormationCreateChangeSet stackName mStackDescription stackTemplate parameters capabilities tags =
+  fmap (first formatServiceError)
     $ trying (_ServiceError . hasStatus 400)
+    $ awsSilently
     $ do
-        name <- newChangeSetName
+      name <- newChangeSetName
 
-        logDebug $ "Reading Template" :# ["path" .= stackTemplate]
-        templateBody <- addStackDescription mStackDescription
+      logDebug $ "Reading Template" :# ["path" .= stackTemplate]
+      templateBody <-
+        addStackDescription mStackDescription
           <$> readFileUtf8 (unStackTemplate stackTemplate)
 
-        mStack <- awsCloudFormationDescribeStackMaybe stackName
+      mStack <- awsCloudFormationDescribeStackMaybe stackName
 
-        let
-          changeSetType = fromMaybe ChangeSetType_CREATE $ do
+      let changeSetType = fromMaybe ChangeSetType_CREATE $ do
             stack <- mStack
-            pure $ if stackIsAbandonedCreate stack
-              then ChangeSetType_CREATE
-              else ChangeSetType_UPDATE
+            pure
+              $ if stackIsAbandonedCreate stack
+                then ChangeSetType_CREATE
+                else ChangeSetType_UPDATE
 
-        let
-          req =
+      let req =
             newCreateChangeSet (unStackName stackName) (unChangeSetName name)
               & (createChangeSet_changeSetType ?~ changeSetType)
               . (createChangeSet_templateBody ?~ templateBody)
@@ -387,17 +407,17 @@ awsCloudFormationCreateChangeSet stackName mStackDescription stackTemplate param
               . (createChangeSet_capabilities ?~ capabilities)
               . (createChangeSet_tags ?~ tags)
 
-        logInfo
-          $ "Creating changeset..."
-          :# ["name" .= name, "type" .= changeSetType]
-        csId <- awsSimple "CreateChangeSet" req (^. createChangeSetResponse_id)
+      logInfo
+        $ "Creating changeset..."
+        :# ["name" .= name, "type" .= changeSetType]
+      csId <- awsSimple req (^. createChangeSetResponse_id)
 
-        logDebug "Awaiting CREATE_COMPLETE"
-        void $ awsAwait newChangeSetCreateComplete $ newDescribeChangeSet csId
+      logDebug "Awaiting CREATE_COMPLETE"
+      void $ awsAwait newChangeSetCreateComplete $ newDescribeChangeSet csId
 
-        logInfo "Retrieving changeset..."
-        cs <- awsCloudFormationDescribeChangeSet $ ChangeSetId csId
-        pure $ cs <$ guard (not $ changeSetFailed cs)
+      logInfo "Retrieving changeset..."
+      cs <- awsCloudFormationDescribeChangeSet $ ChangeSetId csId
+      pure $ cs <$ guard (not $ changeSetFailed cs)
 
 awsCloudFormationDescribeChangeSet
   :: (MonadResource m, MonadReader env m, HasAwsEnv env)
@@ -405,21 +425,7 @@ awsCloudFormationDescribeChangeSet
   -> m ChangeSet
 awsCloudFormationDescribeChangeSet changeSetId = do
   let req = newDescribeChangeSet $ unChangeSetId changeSetId
-  awsSimple "DescribeChangeSet" req $ \resp ->
-    ChangeSet
-      <$> (resp ^. describeChangeSetResponse_creationTime)
-      <*> pure (fmap sortChanges $ resp ^. describeChangeSetResponse_changes)
-      <*> (ChangeSetName <$> resp ^. describeChangeSetResponse_changeSetName)
-      <*> (resp ^. describeChangeSetResponse_executionStatus)
-      <*> (ChangeSetId <$> resp ^. describeChangeSetResponse_changeSetId)
-      <*> pure (resp ^. describeChangeSetResponse_parameters)
-      <*> (StackId <$> resp ^. describeChangeSetResponse_stackId)
-      <*> pure (resp ^. describeChangeSetResponse_capabilities)
-      <*> pure (resp ^. describeChangeSetResponse_tags)
-      <*> (StackName <$> resp ^. describeChangeSetResponse_stackName)
-      <*> pure (resp ^. describeChangeSetResponse_status)
-      <*> pure (resp ^. describeChangeSetResponse_statusReason)
-      <*> pure resp
+  awsSimple req changeSetFromResponse
 
 sortChanges :: [Change] -> [Change]
 sortChanges = sortByDependencies changeName changeCausedBy
@@ -452,15 +458,15 @@ awsCloudFormationDeleteAllChangeSets stackName = do
   runConduit
     $ awsPaginate (newListChangeSets $ unStackName stackName)
     .| concatMapC
-         (\resp -> fromMaybe [] $ do
-           ss <- resp ^. listChangeSetsResponse_summaries
-           pure $ mapMaybe Summary.changeSetId ss
-         )
+      ( \resp -> fromMaybe [] $ do
+          ss <- resp ^. listChangeSetsResponse_summaries
+          pure $ mapMaybe Summary.changeSetId ss
+      )
     .| mapM_C
-         (\csId -> do
-           logInfo $ "Enqueing delete" :# ["changeSetId" .= csId]
-           void $ awsSend $ newDeleteChangeSet csId
-         )
+      ( \csId -> do
+          logInfo $ "Enqueing delete" :# ["changeSetId" .= csId]
+          void $ awsSend $ newDeleteChangeSet csId
+      )
 
 -- | Did we abandoned this Stack's first ever ChangeSet?
 --
@@ -474,16 +480,20 @@ awsCloudFormationDeleteAllChangeSets stackName = do
 -- Our hueristic for finding these is under review but with no previous
 -- updates (no lastUpdatedTime), presumably meaning it's still in its /first/
 -- review.
---
 stackIsAbandonedCreate :: Stack -> Bool
 stackIsAbandonedCreate stack =
-  stack ^. stack_stackStatus == StackStatus_REVIEW_IN_PROGRESS && isNothing
-    (stack ^. stack_lastUpdatedTime)
+  stack
+    ^. stack_stackStatus
+    == StackStatus_REVIEW_IN_PROGRESS
+    && isNothing
+      (stack ^. stack_lastUpdatedTime)
 
 stackStatusRequiresDeletion :: Stack -> Maybe StackStatus
-stackStatusRequiresDeletion stack = status
-  <$ guard (status `elem` requiresDeletionStatuses)
-  where status = stack ^. stack_stackStatus
+stackStatusRequiresDeletion stack =
+  status
+    <$ guard (status `elem` requiresDeletionStatuses)
+ where
+  status = stack ^. stack_stackStatus
 
 requiresDeletionStatuses :: [StackStatus]
 requiresDeletionStatuses =
@@ -499,9 +509,3 @@ runningStatuses =
 _ValidationError :: AsError a => Getting (First ServiceError) a ServiceError
 _ValidationError =
   _MatchServiceError defaultService "ValidationError" . hasStatus 400
-
-formatServiceError :: ServiceError -> Text
-formatServiceError e = mconcat
-  [ toText $ e ^. serviceCode
-  , maybe "" ((": " <>) . toText) $ e ^. serviceMessage
-  ]
