@@ -11,31 +11,35 @@
 --     run:
 --       InvokeLambdaByStackOutput: OnDeployFunction
 -- @
---
 module Stackctl.Action
   ( Action
   , newAction
-  , ActionOn(..)
-  , ActionRun(..)
+  , ActionOn (..)
+  , ActionRun (..)
   , runActions
   ) where
 
 import Stackctl.Prelude hiding (on)
 
+import Blammo.Logging.Logger (flushLogger)
 import Data.Aeson
 import Data.List (find)
+import qualified Data.List.NonEmpty as NE
 import Stackctl.AWS
 import Stackctl.AWS.Lambda
+import Stackctl.OneOrListOf
+import qualified Stackctl.OneOrListOf as OneOrListOf
+import System.Process.Typed
 
 data Action = Action
   { on :: ActionOn
-  , run :: ActionRun
+  , run :: OneOrListOf ActionRun
   }
   deriving stock (Eq, Show, Generic)
   deriving anyclass (FromJSON, ToJSON)
 
-newAction :: ActionOn -> ActionRun -> Action
-newAction = Action
+newAction :: ActionOn -> [ActionRun] -> Action
+newAction on runs = Action {on, run = OneOrListOf.fromList runs}
 
 data ActionOn = PostDeploy
   deriving stock (Eq, Show, Generic)
@@ -55,29 +59,45 @@ instance ToJSON ActionOn where
 data ActionRun
   = InvokeLambdaByStackOutput Text
   | InvokeLambdaByName Text
+  | Exec (NonEmpty String)
+  | Shell String
   deriving stock (Eq, Show)
 
 instance FromJSON ActionRun where
   parseJSON = withObject "ActionRun" $ \o ->
     (InvokeLambdaByStackOutput <$> o .: "InvokeLambdaByStackOutput")
       <|> (InvokeLambdaByName <$> o .: "InvokeLambdaByName")
+      <|> (Exec <$> o .: "Exec")
+      <|> (Shell <$> o .: "Shell")
 
 instance ToJSON ActionRun where
-  toJSON = object . \case
-    InvokeLambdaByStackOutput name -> ["InvokeLambdaByStackOutput" .= name]
-    InvokeLambdaByName name -> ["InvokeLambdaByName" .= name]
-  toEncoding = pairs . \case
-    InvokeLambdaByStackOutput name -> "InvokeLambdaByStackOutput" .= name
-    InvokeLambdaByName name -> "InvokeLambdaByName" .= name
+  toJSON =
+    object . \case
+      InvokeLambdaByStackOutput name -> ["InvokeLambdaByStackOutput" .= name]
+      InvokeLambdaByName name -> ["InvokeLambdaByName" .= name]
+      Exec args -> ["Exec" .= args]
+      Shell arg -> ["Shell" .= arg]
+  toEncoding =
+    pairs . \case
+      InvokeLambdaByStackOutput name -> "InvokeLambdaByStackOutput" .= name
+      InvokeLambdaByName name -> "InvokeLambdaByName" .= name
+      Exec args -> "Exec" .= args
+      Shell arg -> "Shell" .= arg
 
 data ActionFailure
   = NoSuchOutput
   | InvokeLambdaFailure
-  deriving stock Show
-  deriving anyclass Exception
+  | ExecFailure ExitCode
+  deriving stock (Show)
+  deriving anyclass (Exception)
 
 runActions
-  :: (MonadResource m, MonadLogger m, MonadReader env m, HasAwsEnv env)
+  :: ( MonadResource m
+     , MonadLogger m
+     , MonadReader env m
+     , HasLogger env
+     , HasAwsEnv env
+     )
   => StackName
   -> ActionOn
   -> [Action]
@@ -86,17 +106,22 @@ runActions stackName on =
   traverse_ (runAction stackName) . filter (`shouldRunOn` on)
 
 shouldRunOn :: Action -> ActionOn -> Bool
-shouldRunOn Action { on } on' = on == on'
+shouldRunOn Action {on} on' = on == on'
 
 runAction
-  :: (MonadResource m, MonadLogger m, MonadReader env m, HasAwsEnv env)
+  :: ( MonadResource m
+     , MonadLogger m
+     , MonadReader env m
+     , HasLogger env
+     , HasAwsEnv env
+     )
   => StackName
   -> Action
   -> m ()
-runAction stackName Action { on, run } = do
+runAction stackName Action {on, run} = do
   logInfo $ "Running action" :# ["on" .= on, "run" .= run]
 
-  case run of
+  for_ run $ \case
     InvokeLambdaByStackOutput outputName -> do
       outputs <- awsCloudFormationDescribeStackOutputs stackName
       case findOutputValue outputName outputs of
@@ -110,6 +135,8 @@ runAction stackName Action { on, run } = do
           throwIO NoSuchOutput
         Just name -> invoke name
     InvokeLambdaByName name -> invoke name
+    Exec args -> execProcessAction (NE.head args) (NE.tail args)
+    Shell arg -> execProcessAction "sh" ["-c", arg]
  where
   invoke name = do
     result <- awsLambdaInvoke name payload
@@ -121,3 +148,15 @@ runAction stackName Action { on, run } = do
 findOutputValue :: Text -> [Output] -> Maybe Text
 findOutputValue name =
   view output_outputValue <=< find ((== Just name) . view output_outputKey)
+
+execProcessAction
+  :: (MonadIO m, MonadLogger m, MonadReader env m, HasLogger env)
+  => String
+  -> [String]
+  -> m ()
+execProcessAction cmd args = do
+  logDebug $ "runProcess" :# ["command" .= (cmd : args)]
+  flushLogger
+
+  ec <- runProcess $ proc cmd args
+  unless (ec == ExitSuccess) $ throwIO $ ExecFailure ec
