@@ -1,5 +1,5 @@
 module Stackctl.Subcommand
-  ( Subcommand(..)
+  ( Subcommand (..)
   , subcommand
   , runSubcommand
   , runSubcommand'
@@ -10,6 +10,7 @@ import Stackctl.Prelude
 
 import qualified Env
 import Options.Applicative
+import Stackctl.AWS (handlingServiceError)
 import Stackctl.AutoSSO
 import Stackctl.CLI
 import Stackctl.ColorOption
@@ -42,12 +43,14 @@ runSubcommand'
   -> Mod CommandFields (options -> IO a)
   -> IO a
 runSubcommand' title parseEnv parseCLI sp = do
-  (options, act) <- applyEnv
-    <$> Env.parse (Env.header $ unpack title) parseEnv
-    <*> execParser (withInfo title $ (,) <$> parseCLI <*> subparser sp)
+  (options, act) <-
+    applyEnv
+      <$> Env.parse (Env.header $ unpack title) parseEnv
+      <*> execParser (withInfo title $ (,) <$> parseCLI <*> subparser sp)
 
   act options
-  where applyEnv env = first (env <>)
+ where
+  applyEnv env = first (env <>)
 
 -- | Use this in the 'run' member of a 'Subcommand' that wants 'AppT'
 --
@@ -60,7 +63,6 @@ runSubcommand' title parseEnv parseCLI sp = do
 -- runFoo :: (MonadReader env m, HasAws env) => FooOptions -> m ()
 -- runFoo = undefined
 -- @
---
 runAppSubcommand
   :: ( HasColorOption options
      , HasVerboseOption options
@@ -70,7 +72,10 @@ runAppSubcommand
   -> subOptions
   -> options
   -> IO a
-runAppSubcommand f subOptions options = runAppT options $ f subOptions
+runAppSubcommand f subOptions options =
+  runAppT options
+    $ handlingServiceError
+    $ f subOptions
 
 withInfo :: Text -> Parser a -> ParserInfo a
 withInfo d p = info (p <**> helper) $ progDesc (unpack d) <> fullDesc
